pub struct CronSchedule { /* private fields */ }Expand description
Defines cron expression used by schedule.
It uses seven items expression: seconds, minutes, hours, days (month), months, days (week), years. Seconds and years can be omitted: if an expression has five items, it runs at second 0 every year; if it has six items - the first item defines seconds.
For more information about valid cron expressions, please refer to cron-lite crate documentation.
It’s possible to use cron expression with timezone if tz feature is enabled.
Examples
use sacs::task::CronSchedule;
let every_minute_1: CronSchedule = "* * * * *".try_into().unwrap();
let every_minute_2: CronSchedule = "0 * * * * *".try_into().unwrap();
assert_eq!(every_minute_1, every_minute_2);
let every_5th_second: CronSchedule = "*/5 * * * * *".try_into().unwrap();
let every_business_hour: CronSchedule = "0 9-18 * * Mon-Fri".try_into().unwrap();
// Every even year every 10 seconds at 9:00-9:01am on January 1st.
let something_senseless: CronSchedule = "*/10 0 9 1 1 ? */2".try_into().unwrap();Trait Implementations
Sourceimpl Clone for CronSchedule
impl Clone for CronSchedule
Sourcefn clone(&self) -> CronSchedule
fn clone(&self) -> CronSchedule
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for CronSchedule
impl Debug for CronSchedule
Sourceimpl Display for CronSchedule
impl Display for CronSchedule
impl Eq for CronSchedule
Sourceimpl PartialEq for CronSchedule
impl PartialEq for CronSchedule
Sourcefn eq(&self, other: &CronSchedule) -> bool
fn eq(&self, other: &CronSchedule) -> bool
Tests for
self and other values to be equal, and is used by ==.impl StructuralPartialEq for CronSchedule
Sourceimpl TryFrom<&String> for CronSchedule
impl TryFrom<&String> for CronSchedule
Sourceimpl TryFrom<&str> for CronSchedule
impl TryFrom<&str> for CronSchedule